using System;
using System.Collections.Generic;
using System.Text;
using System.Reflection;
using System.Diagnostics;

namespace SeSMbUnit
{
    public static class SeSMbUnitHelper
    {
        public static string GetSmarteStudioEnginePath()
        {
            Type helperType = Type.GetTypeFromProgID("SeSHelper");
            if (null != helperType)
            {
                object helperObj = Activator.CreateInstance(helperType);
                if (null != helperObj)
                {
                    object res = helperObj.GetType().InvokeMember("GetEnginePath", BindingFlags.InvokeMethod, null, helperObj, new object[0]);
                    if (null != res)
                    {
                        return "" + res;
                    }
                }
            }
            else
            {
                System.Windows.Forms.MessageBox.Show("SmarteStudio is not installed", "SeSNUnit Helper");
            }
            return null;
        }

        public static string GetSmarteStudioPath()
        {
            string epath = GetSmarteStudioEnginePath();
            if (null != epath)
            {
                System.IO.DirectoryInfo di = new System.IO.DirectoryInfo(epath);
                return di.Parent.FullName;
            }
            return null;
        }

        public static int TestExecute()
        {
            StackTrace stackTrace = new StackTrace();

            object[] attributes = stackTrace.GetFrame(1).GetMethod().GetCustomAttributes(typeof(SeSMbUnitTestAttribute), false);
            foreach (Object attr in attributes)
            {
                if (attr is SeSMbUnitTestAttribute)
                {
                    SeSMbUnitTestAttribute suta = (SeSMbUnitTestAttribute)attr;
                    return TestExecute(suta.Path);
                }
            }
            return -1;
        }

        public static int TestExecute(string path)
        {
            path = path.Replace("%SMARTESTUDIO%", GetSmarteStudioPath());
            path = path.Replace("%ENGINE%", System.IO.Path.Combine(GetSmarteStudioEnginePath(), "\\.."));
            Process myProc = Process.Start("cscript.exe", System.IO.Path.Combine(GetSmarteStudioEnginePath(), "SeSExecutor.js") + " \"" + path + "\"");
            myProc.WaitForExit();

            string testFolderPath = System.IO.Path.GetDirectoryName(path);

            string outPath = System.IO.Path.Combine(testFolderPath, "out.log");
            if (System.IO.File.Exists(outPath))
            {
                Debug.Write(System.IO.File.ReadAllText(outPath));
            }
            string errPath = System.IO.Path.Combine(testFolderPath, "err.log");
            if (System.IO.File.Exists(errPath))
            {
                Console.Error.Write(System.IO.File.ReadAllText(errPath));
            }

            string tapPath = System.IO.Path.Combine(testFolderPath, "last.tap");
            if (System.IO.File.Exists(tapPath))
            {
                Console.Out.Write(System.IO.File.ReadAllText(tapPath));
            }

            return myProc.ExitCode;
        }
    

    }
}